@@ -32,6 +32,8 @@ pub mod create_group_options;
 pub use self::create_group_options::CreateGroupOptions;
 pub mod create_inbox_dto;
 pub use self::create_inbox_dto::CreateInboxDto;
+pub mod create_inbox_ruleset_options;
+pub use self::create_inbox_ruleset_options::CreateInboxRulesetOptions;
 pub mod create_template_options;
 pub use self::create_template_options::CreateTemplateOptions;
 pub mod create_webhook_options;
@@ -92,6 +94,10 @@ pub mod inbox;
 pub use self::inbox::Inbox;
 pub mod inbox_projection;
 pub use self::inbox_projection::InboxProjection;
+pub mod inbox_ruleset_dto;
+pub use self::inbox_ruleset_dto::InboxRulesetDto;
+pub mod inbox_ruleset_projection;
+pub use self::inbox_ruleset_projection::InboxRulesetProjection;
 pub mod ip_address_result;
 pub use self::ip_address_result::IpAddressResult;
 pub mod match_option;
@@ -122,6 +128,8 @@ pub mod page_group_projection;
 pub use self::page_group_projection::PageGroupProjection;
 pub mod page_inbox_projection;
 pub use self::page_inbox_projection::PageInboxProjection;
+pub mod page_inbox_ruleset_projection;
+pub use self::page_inbox_ruleset_projection::PageInboxRulesetProjection;
 pub mod page_missed_email_projection;
 pub use self::page_missed_email_projection::PageMissedEmailProjection;
 pub mod page_organization_inbox_projection;
